JsonType class

Inheritance

Constructors

JsonType()
const

Properties

codec → Codec<Object, String>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
pgType → PgType
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeName → String
finalinherited

Methods

mapToSqlLiteral(GenerationContext context, Object dartValue) → String
Maps the dartValue to a SQL snippet that can be embedded as a literal into SQL queries generated by drift.
inherited
mapToSqlParameter(GenerationContext context, Object dartValue) → Object
Maps the dartValue to a value understood by the underlying database driver.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(SqlTypes types, Object fromSql) → Object
Interprets the underlying fromSql value from the database driver into the Dart representation T of this type.
inherited
sqlTypeName(GenerationContext context) → String
Returns a suitable representation of this type in SQL.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited